#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
%global		__python	/usr/bin/python3
%global		sname		snowballstemmer

#-----------------------------------------------------------------------------
Name		:	snowball
Version		:	2.2.0
Release		:	17.2.0.rel%{?dist}
Summary		:	Snowball compiler and stemming algorithms

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	BSD-3-Clause
URL		:	https://github.com/snowballstem/snowball/

Source0		:	%{name}-%{version}.tar.gz
patch0		:	%{name}-%{version}-dynamiclib.diff.patch

#-----------------------------------------------------------------------------
BuildRequires	:	gcc
BuildRequires	:	make
BuildRequires	:	perl
BuildRequires	:	python3-docutils

#-----------------------------------------------------------------------------
%description
Snowball is a small string processing language for
creating stemming algorithms for use in Information
Retrieval, plus a collection of stemming algorithms
implemented using it.
 
Snowball was originally designed and built by Martin Porter.
Martin retired from development in 2014 and Snowball
is now maintained as a community project.
 Martin originally chose the name Snowball as a tribute
to SNOBOL, the excellent string handling language from the
1960s.  It now also serves as a metaphor for how the
project grows by
gathering contributions over time.
 
#-----------------------------------------------------------------------------
%files
%defattr(-,root,root,-)
%doc NEWS README.html
%license COPYING
%{_bindir}/snowball
%{_bindir}/stemwords

#=============================================================================
%package		-n libstemmer-devel
Summary		:	Development package for %{name}

#-----------------------------------------------------------------------------
Requires	:	libstemmer		= %{version}-%{release}

#-----------------------------------------------------------------------------
%description		-n libstemmer-devel
Files for development with %{name}.

#-----------------------------------------------------------------------------
%files			-n libstemmer-devel
%defattr(-,root,root,-)
%doc examples/stemwords.c
%{_includedir}/libstemmer.h
%{_libdir}/libstemmer.so

#=============================================================================
%package		-n libstemmer
Summary		:	Files for installed tests

#-----------------------------------------------------------------------------
Requires	:	%{name}		= %{version}-%{release}

#-----------------------------------------------------------------------------
%description		-n libstemmer
Executable and data files for installed tests.

#-----------------------------------------------------------------------------
%files			-n libstemmer
%defattr(-,root,root,-)
%doc libstemmer/README.html
%license COPYING
%{_libdir}/libstemmer.so.0*

#=============================================================================
%package		-n python3-libstemmer
Summary		:	Stemming algorithms written in Python 3

#-----------------------------------------------------------------------------
Requires	:	%{name}		= %{version}-%{release}

BuildArch	:	noarch

#-----------------------------------------------------------------------------
%description		-n python3-libstemmer
Stemming algorithms written in Python 3

Snowball is a small string processing language for
creating stemming algorithms for use in Information
Retrieval, plus a collection of stemming algorithms
implemented using it.
 
#-----------------------------------------------------------------------------
%files			-n python3-libstemmer
%defattr(-,root,root,-)
%doc python/README.html
%license COPYING
%{python3_sitelib}/%{sname}/*.py
%{python3_sitelib}/%{sname}/__pycache__/*.pyc
%{python3_sitelib}/%{sname}-%{version}.dist-info/

#=============================================================================
%prep
%setup -q
%patch -P 0 -p1

# Fix an RST error
sed -i 's/\(libstemmer_c-\)\*/\1\\*/' doc/libstemmer_c_README

#-----------------------------------------------------------------------------
#building application
%build

%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
%{__make} %{_smp_mflags}

# Build the python algorithms
%{__make} %{_smp_mflags} dist_libstemmer_python

pushd dist
tar xf snowballstemmer-%{version}.tar.*
popd

pushd dist/snowballstemmer-%{version}
%{__python}						\
	-m build					\
	--wheel						\
	--no-isolation

popd

# Convert the RST docs to HTML for readability
rst2html --no-datestamp README.rst README.html
rst2html --no-datestamp doc/libstemmer_c_README libstemmer/README.html
rst2html --no-datestamp doc/libstemmer_java_README java/README.html
rst2html --no-datestamp doc/libstemmer_python_README python/README.html

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#testing program
%check

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

#------------------------------------------------------
# Install the snowball compiler
%{__mkdir_p}					\
	%{buildroot}%{_bindir}

%{__cp} -p					\
	snowball				\
	stemwords				\
	%{buildroot}%{_bindir}

#------------------------------------------------------
# Install the C library

install						\
	-m644					\
	-Dt %{buildroot}%{_includedir}		\
	include/libstemmer.h

install						\
	-Dm644					\
	libstemmer.so.0				\
	%{buildroot}%{_libdir}/libstemmer.so.0.0.0

%{__ln_s}					\
	libstemmer.so.0.0.0 			\
	%{buildroot}%{_libdir}/libstemmer.so.0

%{__ln_s}					\
	libstemmer.so.0 			\
	%{buildroot}%{_libdir}/libstemmer.so

# Install the python algorithms
pushd dist/snowballstemmer-%{version}
%{__python}						\
	-m installer					\
	--destdir %{buildroot}				\
	dist/*.whl
popd
#-----------------------------------------------------------------------------
%changelog
